@@ -245,7 +245,8 @@ class ROC(object):
             verbose = False,
             print_cutoff = False,
             no_plot = False,
-            output_dir = OUTPUT_DIR
+            output_dir = OUTPUT_DIR,
+            cache_dir = ''
     ):
         self.args = args
 
@@ -264,9 +265,11 @@ class ROC(object):
         self.print_cutoff = args.print_cutoff if args else print_cutoff
         self.tempdir = args.tempdir if args else tempdir
         self.no_plot = args.no_plot if args else no_plot
+        self.cache_dir = args.cache_dir if args else cache_dir
+        self.merge_dir = os.path.join(self.cache_dir, MERGE_DIR)
+        self.sort_dir = os.path.join(self.cache_dir, SORT_DIR)
         self.output_dir = args.output_dir if args else output_dir
 
-
     def plotCurves(self, dataByModel):
         """
         Plot ROC, PR and Correlation Curves by model.
@@ -365,8 +368,8 @@ class ROC(object):
         Group data to separated file by model.
         """
         t1 = time.time()
-        print("merging files by model to %s" % MERGE_DIR)
-        ensure_dir(MERGE_DIR)
+        print("merging files by model to")
+        ensure_dir(self.merge_dir)
         fileByModel = dict()
         randomByModel = dict()
         totalLineMerged = 0
@@ -381,7 +384,7 @@ class ROC(object):
                             continue
                     model = fields[0]
                     if model not in fileByModel:
-                        fileByModel[model] = open('%s/%s.txt' % (MERGE_DIR, model), 'w')
+                        fileByModel[model] = open('%s/%s.txt' % (self.merge_dir, model), 'w')
                         randomByModel[model] = random.Random()
 
                     if self.sample >= 1.0 or randomByModel[model].random() < self.sample:
@@ -436,11 +439,11 @@ class ROC(object):
         """
         t1 = time.time()
         print("sorting files....")
-        ensure_dir(SORT_DIR)
+        ensure_dir(self.sort_dir)
         processPool = []
         for model in list(fileByModel.keys()):
-            mergedFile = '%s/%s.txt' % (MERGE_DIR, model)
-            sortedFile = '%s/%s.txt' % (SORT_DIR, model)
+            mergedFile = '%s/%s.txt' % (self.merge_dir, model)
+            sortedFile = '%s/%s.txt' % (self.sort_dir, model)
             if self.ignore_invalid:
                 key = eval('lambda l: -float(l.split("' + self.delimiter +
                            '")[2] or 0.0)')
@@ -467,7 +470,7 @@ class ROC(object):
         dataByModel = dict()
         resultList = []
         for model in list(fileByModel.keys()):
-            sortedFile = '%s/%s.txt' % (SORT_DIR, model)
+            sortedFile = '%s/%s.txt' % (self.sort_dir, model)
             result = pool.apply_async(computeMetrics, args=(model, sortedFile, self.shard_count, self.delimiter, self.print_cutoff))
             resultList.append(result)
         for result in resultList:
@@ -517,13 +520,13 @@ class ROC(object):
                 print(fileByModel)
             phrase = PHRASE_GROUP + 1
         else:
-            fileByModel = self.loadFileNameByModel(MERGE_DIR)
+            fileByModel = self.loadFileNameByModel(self.merge_dir)
 
         if phrase == PHRASE_SORT:
             self.sortDataFileByModel(fileByModel)
             phrase = PHRASE_SORT + 1
         else:
-            fileByModel = self.loadFileNameByModel(SORT_DIR)
+            fileByModel = self.loadFileNameByModel(self.sort_dir)
 
         if phrase == PHRASE_PROCESS:
             dataByModel = self.processDataByModel(fileByModel)
@@ -642,7 +645,12 @@ def main():
     parser.add_argument('--output-dir',
                         dest='output_dir',
                         default=OUTPUT_DIR,
-                        help='output data file')
+                        help='output data dir')
+
+    parser.add_argument('--cache-dir',
+                        dest='cache_dir',
+                        default='',
+                        help='cache data dir')
 
     args = parser.parse_args()
     print('Args:', args)
